# fuelcell

fuelcell is a python package to streamline process of analyzing data generated from common electrochemical experiments

## Installation

fuelcell can be installed using the package manager [pip](https://pypi.org) 

``` bash
pip install fuelcell
```

## Version 1.1.0

* Added support for error calculations and error bars
* Updated visualisation methods to improve pass-through to matplotlib
* Bug fixes and minor improvements

## License

[MIT](https://choosealicense.com/licenses/mit/) 